% 2022-04-06 10:59 plot fusion ideal ignition condition
% 22-04-09 22:07 update with Te/Ti<1
close all;clear;clc;

% constants
kB=1.3807e-23; % J/K
qe=1.6022e-19; % C
% me=9.1094e-31; % kg
mp=1.6726e-27; % kg
% epsilon0=8.8542e-12; % F/m
% mu0=4e-7*pi; % H/m
% c=2.99792458e8; % m/s

md=2*mp;
mt=3*mp;
mhe=3*mp;
mb=11*mp;

Teff=1:0.1:1000.0; % keV
Te=Teff;

ne=1e20;
mec2=511; % keV
% Pbrem=1.69e-32*(ne*1e-6)^2.*sqrt(1e3*Te).*(Zeff*(1+0.7936*(Te./mec2)+...
%     1.874*(Te./mec2).^2)+3/sqrt(2)*(Te./mec2))*1e6; % W/m^3
Pbrem=1.69e-32*(ne*1e-6)^2.*sqrt(1e3*Te)*1e6; % W/m^3, Pbrem/Zeff
Zeff=1;
Pbremrel=1.69e-32*(ne*1e-6)^2.*sqrt(1e3*Te).*((1+0.7936*(Te./mec2)+...
    1.874*(Te./mec2).^2)+3/sqrt(2)*(Te./mec2)/Zeff)*1e6; % W/m^3

for icase=1:4
    delta12=0;
    
    if(icase==1)
        
        Z1=1.0; Z2=1.0;
        x1=0.5; x2=1-x1;
        Zi=x1*Z1+x2*Z2;
        Zeff=(x1*Z1^2+x2*Z2^2)/(x1*Z1+x2*Z2);
        ni=ne/Zi; n1=ni*x1; n2=ni*x2;
        
%         Ydt=17.59*1e6*qe; % MeV -> J
        Ydt=3.52*1e6*qe; % MeV -> J
        sgmvdt=fsgmv(Teff,1);
        Pfusdt=(n1*n2*sgmvdt)/(1+delta12)*Ydt/Zeff;
        
    elseif(icase==2)
        delta12=1; % like particle, =1
        
        Z=1; Zi=1; Zeff=1;
        n1=ne; n2=ne;
        
%         (3.03+1.01+2.45+0.82+14.07+3.52+14.68+3.67)

%         Ydd=0.5*(3.27*3/4+4.04)*1e6*qe; % MeV -> J
%         Yddc=0.5*(3.03+1.01/5+0*2.45+0.82+0*14.07+3.52+14.68+3.67)*1e6*qe; % MeV -> J
        Ydd=0.5*(3.27*1/4+4.04)*1e6*qe; % MeV -> J
        Yddc=0.5*26.73*1e6*qe; % MeV -> J
        sgmvdd=fsgmv(Teff,2);
        Pfusdd=(n1*n2*sgmvdd)/(1+delta12)*Ydd/Zeff;
        Pfusddc=(n1*n2*sgmvdd)/(1+delta12)*Yddc/Zeff;
        
    elseif(icase==3)
        
        Z1=1.0; Z2=2.0;
        x1=0.739; x2=1-x1;
        Zi=x1*Z1+x2*Z2;
        Zeff=(x1*Z1^2+x2*Z2^2)/(x1*Z1+x2*Z2);
        ni=ne/Zi; n1=ni*x1; n2=ni*x2;
        
        Ydhe=18.35*1e6*qe; % MeV -> J
        sgmvdhe=fsgmv(Teff,3);
        Pfusdhe=(n1*n2*sgmvdhe)/(1+delta12)*Ydhe/Zeff;
        
    elseif(icase==4)
        
        Z1=1.0; Z2=5.0;
        x1=0.918; x2=1-x1;
        Zi=x1*Z1+x2*Z2;
        Zeff=(x1*Z1^2+x2*Z2^2)/(x1*Z1+x2*Z2);
        ni=ne/Zi; n1=ni*x1; n2=ni*x2;
        
        Ypb=8.68*1e6*qe; % MeV -> J
        sgmvpb4=fsgmv(Teff,4);
        sgmvpb=fsgmv(Teff,5);
        Pfuspb4=(n1*n2*sgmvpb4)/(1+delta12)*Ypb/Zeff;
        Pfuspb=(n1*n2*sgmvpb)/(1+delta12)*Ypb/Zeff;
        
        Te=Teff/1;
        PbremrelTi1=1.69e-32*(ne*1e-6)^2.*sqrt(1e3*Te).*((1+0.7936*(Te./mec2)+...
            1.874*(Te./mec2).^2)+3/sqrt(2)*(Te./mec2)/Zeff)*1e6; % W/m^3
        Te=Teff/2;
        PbremrelTi2=1.69e-32*(ne*1e-6)^2.*sqrt(1e3*Te).*((1+0.7936*(Te./mec2)+...
            1.874*(Te./mec2).^2)+3/sqrt(2)*(Te./mec2)/Zeff)*1e6; % W/m^3
        Te=Teff/3;
        PbremrelTi3=1.69e-32*(ne*1e-6)^2.*sqrt(1e3*Te).*((1+0.7936*(Te./mec2)+...
            1.874*(Te./mec2).^2)+3/sqrt(2)*(Te./mec2)/Zeff)*1e6; % W/m^3
    end
end

% Pressure

%%
close all;
figure('unit','normalized','DefaultAxesFontSize',16,...
    'DefaultAxesFontWeight','bold',...
    'DefaultAxesLineWidth',2,...
    'position',[0.01,0.2,0.65,0.6]);

ax1=axes('Position',[0.1,0.14,0.84,0.8]);
% subplot(121);
loglog(Teff,Pfusdt,Teff,Pfusdd,Teff,Pfusdhe,Teff,Pfuspb,...
    Teff,Pfuspb4,'-.',Teff,Pfusddc,'--',...
    Teff,Pbrem,':',... %Teff,Pbremrel,':',
    Teff,PbremrelTi1,':',Teff,PbremrelTi3,':','linewidth',3); hold on;
xlabel('T_i [keV]');
ylim([1e3,2e6]);
% xlim([1,500]);
ylabel('P/Z_{eff} [W/m^{3}]');
text(1.2e0,0.5e6,['n_e=',num2str(ne,3),'m^{-3}',10,'T_e=T_i',10,...
    'p-B Z_{eff}=',num2str(Zeff,3)],'FontSize',14);
grid on; set(gca,'YMinorGrid','off','XMinorGrid','off');

% leg1=legend('D-T',...
%     'D-D',...
%     'D-^3He',...
%     'p-^{11}B Sikora',...
%     'p-^{11}B Nevins',...
%     ['Catalyzed',10, 'D-D'],...
%     'Brem radiation',...
%     ['Relativistic',10, 'Brem radiation'],...
%     ['Relativistic T_i/T_e=3',10, 'Brem radiation'],...
%     'Location','southeast');
leg1=legend('D-T',...
    'D-D',...
    'D-^3He',...
    'p-^{11}B Sikora',...
    'p-^{11}B Nevins',...
    ['߻D-D'],...
    '·',...
    ['·'],...
    ['T_i/T_e=3·'],...
    'Location','southeast');
legend('boxoff');
set(leg1,'FontSize',12);

%
% % set(gca,'LooseInset',[0,0,0,0]);

set(gcf,'Units','inches');
screenposition = get(gcf,'Position');
set(gcf,'PaperPositionMode','Auto','PaperUnits',...
    'Inches','PaperSize',[screenposition(3:4)]);
% set(gcf,'PaperPosition',[0 0 screenposition(3:4)],...
%     'PaperSize',[screenposition(3:4)]);
print(gcf,'-dpdf','-painters','idealTi.pdf');

%%
clc;
Pfus=Pfusdt;
% Pfus=Pfusdd;
% Pfus=Pfusddc;
% Pfus=Pfusdhe;
% Pfus=Pfuspb;
% Pfus=Pfuspb4;
P1=abs(Pbrem-Pfus);  P1=P1(1:floor(0.2*length(Teff)));
P2=abs(Pbremrel-Pfus);  P2=P2(1:floor(0.5*length(Teff)));
ind1=find(P1==min(P1));
ind2=find(P2==min(P2));
Teff(ind1)
Teff(ind2)



%% calculate the best n1:n2
if(1==0)
close all;
clear;clc;
% Z1=1; Z2=1; % x=0.5; Zi=1; Zeff=1;
% Z1=1; Z2=2; % x=0.739; Zi=1.261; Zeff=1.414;
Z1=1; Z2=5; % x=0.918; Zi=1.328; Zeff=2.235;
x=0.01:0.001:0.99;
fx=x.*(1-x)./(x*(Z1-Z2)+Z2)./(x*(Z1^2-Z2^2)+Z2^2);
x1=x(fx==max(fx))
Zi=(x1*(Z1-Z2)+Z2)
Zeff=(x1*(Z1^2-Z2^2)+Z2^2)/(x1*(Z1-Z2)+Z2)
plot(x,fx);
end
